@@ -25,7 +25,7 @@ use strict;
 use warnings;
 no warnings;
 
-our $VERSION = '2.135';
+our $VERSION = '2.136';
 
 use Carp qw(carp croak);
 use File::Basename qw(dirname);
@@ -88,6 +88,15 @@ Do you want debugging output? Set this to a true value
 Your CPAN password. If you don't set this and you want to upload to
 PAUSE, you should be prompted for it.
 
+=item CPAN_PASS_<USER>
+
+Append the CPAN user ID to C<CPAN_PASS> and use that value to interact
+with PAUSE. This allows people to deal with more than one CPAN account
+(for example, work and personal). If this has no value, it is used
+preferentially to C<CPAN_PASS>.
+
+The CPAN user value comes from the C<cpan_user> release config value.
+
 =back
 
 =head3 C<.releaserc>
@@ -1219,7 +1228,19 @@ Get passwords for CPAN.
 =cut
 
 sub check_for_passwords {
-	if( my $pass = $_[0]->config->cpan_user && $_[0]->get_env_var( "CPAN_PASS" )  ) {
+	my $id = $_[0]->config->cpan_user;
+	unless( defined $id ) {
+		$_[0]->_debug( "cpan_user is not set. Not looking for password\n" );
+		return;
+		}
+
+	my $per_user_env_key = uc( "CPAN_PASS_$id" );
+	if( exists $ENV{$per_user_env_key} and length $ENV{$per_user_env_key} ) {
+		$_[0]->_debug( "Found env $per_user_env_key\n" );
+		$_[0]->config->set( 'cpan_pass', $ENV{$per_user_env_key} );
+		}
+	elsif( my $pass = $_[0]->config->cpan_user && $_[0]->get_env_var( "CPAN_PASS" )  ) {
+		$_[0]->_debug( "Used get_env_var to get CPAN_PASS\n" );
 		$_[0]->config->set( 'cpan_pass', $pass );
 		}
 
@@ -1340,6 +1361,7 @@ sub get_env_var {
 	my $pass = $ENV{$field};
 
 	return $pass if defined( $pass ) && length( $pass );
+	return if $field =~ m/\ACPAN_PASS_/;
 
 	$self->_print( "$field is not set.  Enter it now: " );
 	if ($field eq 'CPAN_PASS') {
@@ -1457,7 +1479,7 @@ brian d foy, C<< <briandfoy@pobox.com> >>
 
 =head1 COPYRIGHT AND LICENSE
 
-Copyright © 2007-2024, brian d foy C<< <briandfoy@pobox.com> >>. All rights reserved.
+Copyright © 2007-2025, brian d foy C<< <briandfoy@pobox.com> >>. All rights reserved.
 
 This program is free software; you can redistribute it and/or modify
 it under the Artistic License 2.0.
